@@ -50,6 +50,7 @@ class MapEntityTest(TestCase):
     api_prefix = '/api/'
     expected_json_geom = {}
     maxDiff = None
+    user = None
 
     def get_expected_json_attrs(self):
         return {}
@@ -58,14 +59,16 @@ class MapEntityTest(TestCase):
         if os.path.exists(settings.MEDIA_ROOT):
             self.tearDown()
         os.makedirs(settings.MEDIA_ROOT)
+        if self.user:
+            self.client.force_login(user=self.user)
 
     def tearDown(self):
         shutil.rmtree(settings.MEDIA_ROOT)
 
-    def login(self):
-        self.user = self.userfactory(password='booh')
-        success = self.client.login(username=self.user.username, password='booh')
-        self.assertTrue(success)
+    @classmethod
+    def setUpTestData(cls):
+        if cls.userfactory:
+            cls.user = cls.userfactory(password='booh')
 
     def logout(self):
         self.client.logout()
@@ -93,10 +96,8 @@ class MapEntityTest(TestCase):
             return  # Abstract test should not run
 
         # Make sure database is not empty for this model
-        for i in range(30):
-            self.modelfactory.create()
+        self.modelfactory.create_batch(30)
 
-        self.login()
         response = self.client.get(self.model.get_layer_url())
         self.assertEqual(response.status_code, 200)
         response = self.client.get(self.model.get_jsonlist_url())
@@ -110,7 +111,6 @@ class MapEntityTest(TestCase):
         mock_requests.get.return_value.status_code = 200
         mock_requests.get.return_value.content = b'<p id="properties">Mock</p>'
 
-        self.login()
         obj = self.modelfactory.create()
         response = self.client.get(obj.get_document_url())
         self.assertEqual(response.status_code, 200)
@@ -118,7 +118,6 @@ class MapEntityTest(TestCase):
     def test_bbox_filter(self):
         if self.model is None:
             return  # Abstract test should not run
-        self.login()
         params = '?bbox=POLYGON((5+44+0%2C5+45+0%2C6+45+0%2C6+44+0%2C5+44+0))'
         # If no objects exist, should not fail.
         response = self.client.get(self.model.get_jsonlist_url() + params)
@@ -138,7 +137,6 @@ class MapEntityTest(TestCase):
     def test_callback_jsonlist(self):
         if self.model is None:
             return  # Abstract test should not run
-        self.login()
         params = '?callback=json_decode'
         # If no objects exist, should not fail.
         response = self.client.get(self.model.get_jsonlist_url() + params)
@@ -148,7 +146,6 @@ class MapEntityTest(TestCase):
     def test_basic_format(self):
         if self.model is None:
             return  # Abstract test should not run
-        self.login()
         self.modelfactory.create()
         for fmt in ('csv', 'shp', 'gpx'):
             response = self.client.get(self.model.get_format_list_url() + '?format=' + fmt)
@@ -157,7 +154,6 @@ class MapEntityTest(TestCase):
     def test_gpx_elevation(self):
         if self.model is None:
             return  # Abstract test should not run
-        self.login()
         obj = self.modelfactory.create()
         response = self.client.get(self.model.get_format_list_url() + '?format=gpx')
         parsed = BeautifulSoup(response.content, 'lxml')
@@ -169,7 +165,6 @@ class MapEntityTest(TestCase):
     def test_no_basic_format_fail(self):
         if self.model is None:
             return  # Abstract test should not run
-        self.login()
         self.modelfactory.create()
 
         response = self.client.get(self.model.get_format_list_url() + '?format=')
@@ -179,8 +174,6 @@ class MapEntityTest(TestCase):
         if self.model is None:
             return  # Abstract test should not run
 
-        self.login()
-
         self.modelfactory.create()
 
         fmt = 'csv'
@@ -244,8 +237,6 @@ class MapEntityTest(TestCase):
         if self.model is None:
             return  # Abstract test should not run
 
-        self.login()
-
         obj = self.modelfactory()
 
         response = self.client.get(obj.get_list_url())
@@ -285,7 +276,6 @@ class MapEntityTest(TestCase):
     def test_formfilter_in_list_context(self):
         if self.model is None:
             return  # Abstract test should not run
-        self.login()
         response = self.client.get(self.model.get_list_url())
         self.assertEqual(response.status_code, 200)
         self.assertTrue(response.context['filterform'] is not None)
@@ -302,7 +292,6 @@ class MapEntityTest(TestCase):
             return
         if self.model is None:
             return  # Abstract test should not run
-        self.login()
 
         self.obj = self.modelfactory.create()
         list_url = '{api_prefix}{modelname}s.json'.format(api_prefix=self.api_prefix,
@@ -321,7 +310,6 @@ class MapEntityTest(TestCase):
             return
         if self.model is None:
             return  # Abstract test should not run
-        self.login()
 
         self.obj = self.modelfactory.create()
         list_url = '{api_prefix}{modelname}s.geojson'.format(api_prefix=self.api_prefix,
@@ -348,7 +336,6 @@ class MapEntityTest(TestCase):
             return
         if self.model is None:
             return  # Abstract test should not run
-        self.login()
 
         self.obj = self.modelfactory.create()
         detail_url = '{api_prefix}{modelname}s/{id}'.format(api_prefix=self.api_prefix,
@@ -369,7 +356,6 @@ class MapEntityTest(TestCase):
             return
         if self.model is None:
             return  # Abstract test should not run
-        self.login()
 
         self.obj = self.modelfactory.create()
         detail_url = '{api_prefix}{modelname}s/{id}.geojson'.format(api_prefix=self.api_prefix,
